@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: main.c 8929 2009-08-14 12:53:08Z charles $
+ * $Id: main.c 9093 2009-09-10 17:39:44Z charles $
  *
  * Copyright (c) 2005-2008 Transmission authors and contributors
  *
@@ -418,8 +418,9 @@ main( int argc, char ** argv )
     {
         /* There's already another copy of Transmission running,
          * so tell it to present its window to the user */
-        gtr_dbus_present_window( );
         err = NULL;
+        if( !gtr_dbus_present_window( ) )
+            err = g_strdup( _( "Transmission is already running, but is not responding.  To start a new session, you must first close the existing Transmission process." ) );
     }
 
     if( didlock && ( didinit || cf_init( configDir, &err ) ) )
@@ -1328,6 +1329,10 @@ doAction( const char * action_name, gpointer user_data )
         GtkWidget * dialog = stats_dialog_create( data->wind, data->core );
         gtk_widget_show( dialog );
     }
+    else if( !strcmp( action_name, "donate" ) )
+    {
+        gtr_open_file( "http://www.transmissionbt.com/donate.php" );
+    }
     else if( !strcmp( action_name, "start-torrent" ) )
     {
         GtkTreeSelection * s = tr_window_get_selection( data->wind );
