@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: tr-core.h 8763 2009-06-30 18:08:50Z charles $
+ * $Id: tr-core.h 8889 2009-08-10 20:04:08Z charles $
  *
  * Copyright (c) 2007-2008 Transmission authors and contributors
  *
@@ -85,10 +85,9 @@ TrCoreClass;
 
 enum tr_core_err
 {
-    TR_CORE_ERR_ADD_TORRENT_ERR  = TR_EINVALID,
-    TR_CORE_ERR_ADD_TORRENT_DUP  = TR_EDUPLICATE,
-    TR_CORE_ERR_NO_MORE_TORRENTS,  /* finished adding a batch */
-    TR_CORE_ERR_SAVE_STATE         /* error saving state */
+    TR_CORE_ERR_ADD_TORRENT_ERR  = TR_PARSE_ERR,
+    TR_CORE_ERR_ADD_TORRENT_DUP  = TR_PARSE_DUPLICATE,
+    TR_CORE_ERR_NO_MORE_TORRENTS = 1000 /* finished adding a batch */
 };
 
 GType          tr_core_get_type( void );
@@ -140,7 +139,7 @@ gboolean tr_core_add_metainfo( TrCore      * core,
 void tr_core_add_torrent( TrCore*, TrTorrent*, gboolean doNotify );
 
 /** Present the main window */
-gboolean tr_core_present_window( TrCore*, gboolean * setme_success, GError ** err ); 
+gboolean tr_core_present_window( TrCore*, gboolean * setme_success, GError ** err );
 
 
 /**
@@ -200,6 +199,8 @@ enum
     MC_NAME_COLLATED,
     MC_TORRENT,
     MC_TORRENT_RAW,
+    MC_SPEED_UP,
+    MC_SPEED_DOWN,
     MC_ACTIVITY,
     MC_ROW_COUNT
 };
