@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: fdlimit.c 8823 2009-07-17 17:23:03Z charles $
+ * $Id: fdlimit.c 8960 2009-08-17 18:49:21Z jhujhiti $
  *
  * Copyright (c) 2005-2008 Transmission authors and contributors
  *
@@ -181,15 +181,15 @@ preallocateFileFull( const char * filename, uint64_t length )
 
         if( !success ) /* if nothing else works, do it the old-fashioned way */
         {
-            uint8_t buf[ 4096 ]; 
-            memset( buf, 0, sizeof( buf ) ); 
-            success = TRUE; 
-            while ( success && ( length > 0 ) ) 
-            { 
-                const int thisPass = MIN( length, sizeof( buf ) ); 
-                success = write( fd, buf, thisPass ) == thisPass; 
-                length -= thisPass; 
-            } 
+            uint8_t buf[ 4096 ];
+            memset( buf, 0, sizeof( buf ) );
+            success = TRUE;
+            while ( success && ( length > 0 ) )
+            {
+                const int thisPass = MIN( length, sizeof( buf ) );
+                success = write( fd, buf, thisPass ) == thisPass;
+                length -= thisPass;
+            }
         }
 
         close( fd );
@@ -316,7 +316,7 @@ TrOpenFile( int                      i,
     if( doWrite && !alreadyExisted && ( preallocationMode == TR_PREALLOCATE_FULL ) )
         if( preallocateFileFull( filename, desiredFileSize ) )
             tr_inf( _( "Preallocated file \"%s\"" ), filename );
-    
+
     /* open the file */
     flags = doWrite ? ( O_RDWR | O_CREAT ) : O_RDONLY;
 #ifdef O_SEQUENTIAL
@@ -446,7 +446,7 @@ tr_fdFileCheckout( int                      torrentId,
         }
 
         assert( winner >= 0 );
-       
+
         if( fileIsOpen( &gFd->openFiles[winner] ) )
         {
             dbgmsg( "closing file \"%s\"", gFd->openFiles[winner].filename );
@@ -477,21 +477,6 @@ tr_fdFileCheckout( int                      torrentId,
     return o->fd;
 }
 
-void
-tr_fdFileReturn( int fd )
-{
-    struct tr_openfile * o;
-    const struct tr_openfile * end;
-
-    for( o=gFd->openFiles, end=o+gFd->openFileLimit; o!=end; ++o )
-    {
-        if( o->fd != fd )
-            continue;
-        dbgmsg( "releasing file \"%s\"", o->filename );
-        break;
-    }
-}
-
 void
 tr_fdFileClose( const char * filename )
 {
@@ -538,11 +523,9 @@ tr_fdSocketCreate( int domain, int type )
     if( gFd->socketCount < getSocketMax( gFd ) )
         if( ( s = socket( domain, type, 0 ) ) < 0 )
         {
-#ifdef SYS_DARWIN
             if( sockerrno != EAFNOSUPPORT )
-#endif
-            tr_err( _( "Couldn't create socket: %s" ),
-                   tr_strerror( sockerrno ) );
+                tr_err( _( "Couldn't create socket: %s" ),
+                        tr_strerror( sockerrno ) );
         }
 
     if( s > -1 )
@@ -576,28 +559,28 @@ tr_fdSocketAccept( int           b,
 
     if( s >= 0 )
     {
-        /* "The ss_family field of the sockaddr_storage structure will always 
-         * align with the family field of any protocol-specific structure." */ 
-        if( sock.ss_family == AF_INET ) 
+        /* "The ss_family field of the sockaddr_storage structure will always
+         * align with the family field of any protocol-specific structure." */
+        if( sock.ss_family == AF_INET )
         {
             struct sockaddr_in *si;
             union { struct sockaddr_storage dummy; struct sockaddr_in si; } s;
             s.dummy = sock;
             si = &s.si;
-            addr->type = TR_AF_INET; 
-            addr->addr.addr4.s_addr = si->sin_addr.s_addr; 
-            *port = si->sin_port; 
-        } 
-        else 
-        { 
+            addr->type = TR_AF_INET;
+            addr->addr.addr4.s_addr = si->sin_addr.s_addr;
+            *port = si->sin_port;
+        }
+        else
+        {
             struct sockaddr_in6 *si;
             union { struct sockaddr_storage dummy; struct sockaddr_in6 si; } s;
             s.dummy = sock;
             si = &s.si;
-            addr->type = TR_AF_INET6; 
+            addr->type = TR_AF_INET6;
             addr->addr.addr6 = si->sin6_addr;
-            *port = si->sin6_port; 
-        } 
+            *port = si->sin6_port;
+        }
         ++gFd->socketCount;
     }
 
