@@ -3,11 +3,11 @@
  *
  * This file is licensed by the GPL version 2.  Works owned by the
  * Transmission project are granted a special exemption to clause 2(b)
- * so that the bulk of its code can remain under the MIT license. 
+ * so that the bulk of its code can remain under the MIT license.
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: inout.h 7664 2009-01-11 17:46:51Z charles $
+ * $Id: inout.h 8912 2009-08-13 17:25:26Z charles $
  */
 
 #ifndef __TRANSMISSION__
@@ -19,25 +19,30 @@
 
 struct tr_torrent;
 
+/**
+ * @addtogroup file_io File IO
+ * @{
+ */
+
 /**
  * Reads the block specified by the piece index, offset, and length.
  * @return 0 on success, or an errno value on failure.
  */
-int tr_ioRead( const struct tr_torrent * tor,
-               tr_piece_index_t          pieceIndex,
-               uint32_t                  offset,
-               uint32_t                  len,
-               uint8_t *                 setme );
+int tr_ioRead( struct tr_torrent   * tor,
+               tr_piece_index_t      pieceIndex,
+               uint32_t              offset,
+               uint32_t              len,
+               uint8_t             * setme );
 
 /**
  * Writes the block specified by the piece index, offset, and length.
  * @return 0 on success, or an errno value on failure.
  */
-int tr_ioWrite( const struct tr_torrent * tor,
-                tr_piece_index_t          pieceIndex,
-                uint32_t                  offset,
-                uint32_t                  len,
-                const uint8_t *           writeme );
+int tr_ioWrite( struct tr_torrent  * tor,
+                tr_piece_index_t     pieceIndex,
+                uint32_t             offset,
+                uint32_t             len,
+                const uint8_t      * writeme );
 
 /**
  * @brief Test to see if the piece matches its metainfo's SHA1 checksum.
@@ -46,7 +51,7 @@ int tr_ioWrite( const struct tr_torrent * tor,
  *                       get best performance by providing a buffer with
  *                       tor->info.pieceSize bytes.
  */
-tr_bool tr_ioTestPiece( const tr_torrent * tor,
+tr_bool tr_ioTestPiece( tr_torrent       * tor,
                         tr_piece_index_t   piece,
                         void             * optionalBuffer,
                         size_t             optionalBufferLen );
@@ -62,4 +67,5 @@ void     tr_ioFindFileLocation( const tr_torrent * tor,
                                 uint64_t *         fileOffset );
 
 
+/* @} */
 #endif
