@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: session.c 8819 2009-07-17 11:20:30Z livings124 $
+ * $Id: session.c 8967 2009-08-18 16:02:16Z charles $
  */
 
 #include <assert.h>
@@ -47,6 +47,12 @@
 #include "version.h"
 #include "web.h"
 
+enum
+{
+    SAVE_INTERVAL_SECS = 120
+};
+
+
 #define dbgmsg( ... ) \
     do { \
         if( tr_deepLoggingIsActive( ) ) \
@@ -315,15 +321,15 @@ isAltTime( const tr_session * s )
     tr_localtime_r( &now, &tm );
     minutes = tm.tm_hour*60 + tm.tm_min;
     day = tm.tm_wday;
-    
+
     if( !toNextDay )
         withinTime = ( begin <= minutes ) && ( minutes < end );
     else /* goes past midnight */
         withinTime = ( begin <= minutes ) || ( minutes < end );
-    
+
     if( !withinTime )
         return FALSE;
-    
+
     if( toNextDay && (minutes < end) )
         day = (day - 1) % 7;
 
@@ -530,6 +536,31 @@ tr_sessionSaveSettings( tr_session    * session,
     tr_bencFree( &settings );
 }
 
+/***
+****
+***/
+
+/**
+ * Periodically save the .resume files of any torrents whose
+ * status has recently changed.  This prevents loss of metadata
+ * in the case of a crash, unclean shutdown, clumsy user, etc.
+ */
+static void
+onSaveTimer( int foo UNUSED, short bar UNUSED, void * vsession )
+{
+    tr_torrent * tor = NULL;
+    tr_session * session = vsession;
+
+    while(( tor = tr_torrentNext( session, tor )))
+        tr_torrentSave( tor );
+
+    tr_timerAdd( session->saveTimer, SAVE_INTERVAL_SECS, 0 );
+}
+
+/***
+****
+***/
+
 static void tr_sessionInitImpl( void * );
 static void onAltTimer( int, short, void* );
 static void setAltTimer( tr_session * session );
@@ -794,7 +825,7 @@ tr_sessionInitImpl( void * vdata )
     found = tr_bencDictFindInt( &settings, TR_PREFS_KEY_ALT_SPEED_TIME_END, &i );
     assert( found );
     session->altSpeedTimeEnd = i;
-    
+
     found = tr_bencDictFindInt( &settings, TR_PREFS_KEY_ALT_SPEED_TIME_DAY, &i );
     assert( found );
     session->altSpeedTimeDay = i;
@@ -834,6 +865,10 @@ tr_sessionInitImpl( void * vdata )
     evtimer_set( session->altTimer, onAltTimer, session );
     setAltTimer( session );
 
+    session->saveTimer = tr_new0( struct event, 1 );
+    evtimer_set( session->saveTimer, onSaveTimer, session );
+    tr_timerAdd( session->saveTimer, SAVE_INTERVAL_SECS, 0 );
+
     /* first %s is the application name
        second %s is the version number */
     tr_inf( _( "%s %s started" ), TR_NAME, LONG_VERSION_STRING );
@@ -848,7 +883,7 @@ tr_sessionInitImpl( void * vdata )
 #ifdef WITHOUT_DHT
         tr_inf( "DHT disabled by packager." );
 #else
-        tr_dhtInit( session );
+        tr_dhtInit( session, &session->public_ipv4->addr );
 #endif
     }
 }
@@ -1105,7 +1140,7 @@ onAltTimer( int foo UNUSED, short bar UNUSED, void * vsession )
         tr_localtime_r( &now, &tm );
         currentMinute = tm.tm_hour*60 + tm.tm_min;
         day = tm.tm_wday;
-        
+
         isBeginTime = currentMinute == session->altSpeedTimeBegin;
         isEndTime = currentMinute == session->altSpeedTimeEnd;
         if( isBeginTime || isEndTime )
@@ -1113,7 +1148,7 @@ onAltTimer( int foo UNUSED, short bar UNUSED, void * vsession )
             /* if looking at the end date, look at the next day if end time is before begin time */
             if( isEndTime && !isBeginTime && session->altSpeedTimeEnd < session->altSpeedTimeBegin )
                 day = (day - 1) % 7;
-            
+
             isDay = ((1<<day) & session->altSpeedTimeDay) != 0;
 
             if( isDay )
@@ -1171,7 +1206,7 @@ tr_sessionIsSpeedLimited( const tr_session * s, tr_direction d )
 }
 
 /***
-****  Alternative speed limits that are used during scheduled times 
+****  Alternative speed limits that are used during scheduled times
 ***/
 
 void
@@ -1192,7 +1227,7 @@ tr_sessionGetAltSpeed( const tr_session * s, tr_direction d )
     assert( tr_isSession( s ) );
     assert( tr_isDirection( d ) );
 
-    return s->altSpeed[d]; 
+    return s->altSpeed[d];
 }
 
 void
@@ -1305,7 +1340,7 @@ useAltSpeed( tr_session * s, tr_bool enabled, tr_bool byUser )
     {
         s->altSpeedEnabled = enabled;
         s->altSpeedChangedByUser = byUser;
-    
+
         tr_runInEventThread( s, altSpeedToggled, s );
     }
 }
@@ -1427,6 +1462,10 @@ sessionCloseImpl( void * vsession )
     if( session->isDHTEnabled )
         tr_dhtUninit( session );
 
+    evtimer_del( session->saveTimer );
+    tr_free( session->saveTimer );
+    session->saveTimer = NULL;
+
     evtimer_del( session->altTimer );
     tr_free( session->altTimer );
     session->altTimer = NULL;
@@ -1633,7 +1672,7 @@ toggleDHTImpl(  void * data )
     session->isDHTEnabled = !session->isDHTEnabled;
 
     if( session->isDHTEnabled )
-        tr_dhtInit( session );
+        tr_dhtInit( session, &session->public_ipv4->addr );
 }
 
 void
