@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: transmission.h 8772 2009-07-02 02:37:49Z charles $
+ * $Id: transmission.h 8929 2009-08-14 12:53:08Z charles $
  *
  * Copyright (c) 2005-2008 Transmission authors and contributors
  *
@@ -590,7 +590,7 @@ tr_bool  tr_sessionIsSpeedLimited     ( const tr_session *, tr_direction );
 
 
 /***
-****  Alternative speed limits that are used during scheduled times 
+****  Alternative speed limits that are used during scheduled times
 ***/
 
 void     tr_sessionSetAltSpeed        ( tr_session *, tr_direction, int KB_s );
@@ -873,26 +873,36 @@ tr_session* tr_ctorGetSession( const tr_ctor * ctor );
 /* returns NULL if tr_ctorSetMetainfoFromFile() wasn't used */
 const char* tr_ctorGetSourceFile( const tr_ctor * ctor );
 
-#define TR_EINVALID     1
-#define TR_EDUPLICATE   2
+typedef enum
+{
+    TR_PARSE_OK,
+    TR_PARSE_ERR,
+    TR_PARSE_DUPLICATE
+}
+tr_parse_result;
 
 /**
- * Parses the specified metainfo.
- * Returns 0 if it parsed successfully and can be added to Transmission.
- * Returns TR_EINVALID if it couldn't be parsed.
- * Returns TR_EDUPLICATE if it parsed but can't be added.
- *     "download-dir" must be set to test for TR_EDUPLICATE.
+ * @brief Parses the specified metainfo
  *
- * If setme_info is non-NULL and parsing is successful
- * (that is, if TR_EINVALID is not returned), then the parsed
- * metainfo is stored in setme_info and should be freed by the
- * caller via tr_metainfoFree().
+ * @return TR_PARSE_ERR if parsing failed;
+ *         TR_PARSE_OK if parsing succeeded and it's not a duplicate;
+ *         TR_PARSE_DUPLICATE if parsing succeeded but it's a duplicate.
  *
- * If the constructor's session variable is NULL,
- * info.torrent will be NULL and the duplicate check will not be performed.
+ * @param setme_info If parsing is successful and setme_info is non-NULL,
+ *                   the parsed metainfo is stored there and sould be freed
+ *                   by calling tr_metainfoFree() when no longer needed.
+ *
+ * Notes:
+ *
+ * 1. tr_torrentParse() won't be able to check for duplicates -- and therefore
+ *    won't return TR_PARSE_DUPLICATE -- unless ctor's "download-dir" and
+ *    session variable is set.
+ *
+ * 2. setme_info->torrent's value can't be set unless ctor's session variable
+ *    is set.
  */
-int tr_torrentParse( const tr_ctor * ctor,
-                     tr_info       * setme_info_or_NULL );
+tr_parse_result  tr_torrentParse( const tr_ctor  * ctor,
+                                  tr_info        * setme_info_or_NULL );
 
 /** @brief free a metainfo
     @see tr_torrentParse */
@@ -1346,14 +1356,6 @@ tr_torrent_activity;
 
 tr_torrent_activity tr_torrentGetActivity( tr_torrent * );
 
-typedef enum
-{
-    TR_LOCKFILE_SUCCESS = 0,
-    TR_LOCKFILE_EOPEN,
-    TR_LOCKFILE_ELOCK
-}
-tr_lockfile_state_t;
-
 enum
 {
     TR_PEER_FROM_INCOMING  = 0,  /* connections made to the listening port */
@@ -1364,8 +1366,14 @@ enum
     TR_PEER_FROM__MAX
 };
 
-/** Can be used as a mnemonic for "no error" errno */
-#define TR_OK 0
+typedef enum
+{
+    TR_STAT_OK               = 0,
+    TR_STAT_TRACKER_WARNING  = 1,
+    TR_STAT_TRACKER_ERROR    = 2,
+    TR_STAT_LOCAL_ERROR      = 3
+}
+tr_stat_errtype;
 
 /**
  * The current status of a torrent.
@@ -1392,11 +1400,13 @@ typedef struct tr_stat
         becomes unreachable. */
     char *  scrapeURL;
 
-    /** The errno status for this torrent.  0 means everything's fine. */
-    int     error;
+    /** Defines what kind of text is in errorString.
+        @see errorString */
+    tr_stat_errtype error;
 
-    /** Typically an error string returned from the tracker. */
-    char    errorString[128];
+    /** A warning or error message regarding the torrent.
+        @see error */
+    char errorString[128];
 
     /** When tr_stat.status is TR_STATUS_CHECK or TR_STATUS_CHECK_WAIT,
         this is the percentage of how much of the files has been
@@ -1414,7 +1424,7 @@ typedef struct tr_stat
         Range is [0..1]
         @see tr_stat.leftUntilDone */
     float    percentDone;
-    
+
     /** The percentage of the actual ratio to the seed ratio.  This will be
         equal to 1 if the ratio is reached or the torrent is set to seed forever.
         Range is [0..1] */
@@ -1511,15 +1521,17 @@ typedef struct tr_stat
         are moved to `corrupt' or `haveValid'. */
     uint64_t    haveUnchecked;
 
-    /** This is the unmodified string returned by the tracker in response
-        to the torrent's most recent scrape request.  If no request was
-        sent or there was no response, this string is empty. */
-    char    scrapeResponse[64];
+    /**
+     * This is a human-readable string with the last scrape's results.
+     * 1. If an http error occurred, the response code and description is given.
+     * 2. If the tracker gave an error or warning messae, that is given.
+     * 3. If everything went fine, "Success" is given.
+     */
+    char    scrapeResponse[128];
 
-    /** The unmodified string returned by the tracker in response
-        to the torrent's most recent scrape request.  If no request was
-        sent or there was no response, this string is empty. */
-    char    announceResponse[64];
+    /** This is a human-readable string with the last announce's results.
+        Its contents have the same form as scrapeResponse. */
+    char    announceResponse[128];
 
     /** Time the most recent scrape request was sent,
         or zero if one hasn't been sent yet. */
