@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: web.c 8986 2009-08-22 23:22:50Z charles $
+ * $Id: web.c 9072 2009-09-08 19:04:44Z charles $
  */
 
 #include <assert.h>
@@ -27,17 +27,30 @@
 #include "version.h"
 #include "web.h"
 
-/* Use curl_multi_socket_action() instead of curl_multi_perform()
-   if libcurl >= 7.18.2.  See http://trac.transmissionbt.com/ticket/1844 */
-#if LIBCURL_VERSION_NUM >= 0x071202
-    #define USE_CURL_MULTI_SOCKET_ACTION
-#endif
+static tr_bool
+useCurlMultiSocketAction( void )
+{
+    static tr_bool tested = FALSE;
+    static tr_bool useMultiSocketAction;
+
+    if( !tested )
+    {
+        curl_version_info_data * data = curl_version_info( CURLVERSION_NOW );
+        tr_inf( "Using libcurl %s", data->version );
+        /* Use curl_multi_socket_action() instead of curl_multi_perform()
+         * if libcurl >= 7.18.2.  See http://trac.transmissionbt.com/ticket/1844 */
+        useMultiSocketAction = data->version_num >= 0x071202;
+        tested = TRUE;
+    }
+
+    return useMultiSocketAction;
+}
 
 
 enum
 {
     /* arbitrary number */
-    MAX_CONCURRENT_TASKS = 100,
+    MAX_CONCURRENT_TASKS = 256,
 
     /* arbitrary number */
     DEFAULT_TIMER_MSEC = 2500
@@ -199,14 +212,17 @@ addTask( void * vtask )
         curl_easy_setopt( easy, CURLOPT_CONNECTTIMEOUT, 60L );
 
         /* set a time limit for announces & scrapes */
-        if( strstr( task->url, "announce" ) )
-            curl_easy_setopt( easy, CURLOPT_TIMEOUT, 120L );
-        else if( strstr( task->url, "scrape" ) )
+        if( strstr( task->url, "scrape" ) )
+            curl_easy_setopt( easy, CURLOPT_TIMEOUT, 15L );
+        else if( strstr( task->url, "announce" ) )
             curl_easy_setopt( easy, CURLOPT_TIMEOUT, 30L );
+        else
+            curl_easy_setopt( easy, CURLOPT_TIMEOUT, 240L );
 
         curl_easy_setopt( easy, CURLOPT_FOLLOWLOCATION, 1L );
+        curl_easy_setopt( easy, CURLOPT_AUTOREFERER, 1L );
         curl_easy_setopt( easy, CURLOPT_FORBID_REUSE, 1L );
-        curl_easy_setopt( easy, CURLOPT_MAXREDIRS, 16L );
+        curl_easy_setopt( easy, CURLOPT_MAXREDIRS, -1L );
         curl_easy_setopt( easy, CURLOPT_NOSIGNAL, 1L );
         curl_easy_setopt( easy, CURLOPT_PRIVATE, task );
         curl_easy_setopt( easy, CURLOPT_SSL_VERIFYHOST, 0L );
@@ -385,20 +401,23 @@ tr_multi_perform( tr_web * g, int fd )
             g->prev_running, g->still_running );
 
     /* invoke libcurl's processing */
-#ifdef USE_CURL_MULTI_SOCKET_ACTION
-    do {
-        dbgmsg( "calling curl_multi_socket_action..." );
-        mcode = curl_multi_socket_action( g->multi, fd, 0, &g->still_running );
-        fd = CURL_SOCKET_TIMEOUT;
-        dbgmsg( "done calling curl_multi_socket_action..." );
-    } while( mcode == CURLM_CALL_MULTI_SOCKET );
-#else
-    do {
-        dbgmsg( "calling curl_multi_perform..." );
-        mcode = curl_multi_perform( g->multi, &g->still_running );
-        dbgmsg( "done calling curl_multi_perform..." );
-    } while( mcode == CURLM_CALL_MULTI_PERFORM );
-#endif
+    if( useCurlMultiSocketAction( ) )
+    {
+        do {
+            dbgmsg( "calling curl_multi_socket_action..." );
+            mcode = curl_multi_socket_action( g->multi, fd, 0, &g->still_running );
+            fd = CURL_SOCKET_TIMEOUT;
+            dbgmsg( "done calling curl_multi_socket_action..." );
+        } while( mcode == CURLM_CALL_MULTI_SOCKET );
+    }
+    else
+    {
+        do {
+            dbgmsg( "calling curl_multi_perform..." );
+            mcode = curl_multi_perform( g->multi, &g->still_running );
+            dbgmsg( "done calling curl_multi_perform..." );
+        } while( mcode == CURLM_CALL_MULTI_PERFORM );
+    }
     tr_assert( mcode == CURLM_OK, "curl_multi_perform() failed: %d (%s)", mcode, curl_multi_strerror( mcode ) );
     if( mcode != CURLM_OK )
         tr_err( "%s", curl_multi_strerror( mcode ) );
