@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: webseed.c 7664 2009-01-11 17:46:51Z charles $
+ * $Id: webseed.c 8685 2009-06-14 01:00:36Z charles $
  */
 
 #include <assert.h>
@@ -99,7 +99,7 @@ makeURL( tr_webseed *    w,
          const tr_file * file )
 {
     char *            ret;
-    struct evbuffer * out = tr_getBuffer( );
+    struct evbuffer * out = evbuffer_new( );
     const char *      url = w->url;
     const size_t      url_len = strlen( url );
 
@@ -140,7 +140,7 @@ makeURL( tr_webseed *    w,
     }
 
     ret = tr_strndup( EVBUFFER_DATA( out ), EVBUFFER_LENGTH( out ) );
-    tr_releaseBuffer( out );
+    evbuffer_free( out );
     return ret;
 }
 
