@@ -1,7 +1,7 @@
 /******************************************************************************
- * $Id: Controller.h 4423 2008-01-02 16:55:05Z livings124 $
+ * $Id: Controller.h 8842 2009-07-19 19:14:01Z livings124 $
  *
- * Copyright (c) 2005-2008 Transmission authors and contributors
+ * Copyright (c) 2005-2009 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -27,48 +27,52 @@
 #import "PrefsController.h"
 #import "InfoWindowController.h"
 #import "MessageWindowController.h"
+#import "AddWindowController.h"
 #import "DragOverlayWindow.h"
 #import "Badger.h"
-#import "StatusBarView.h"
-#import "FilterButton.h"
-#import "MenuLabel.h"
-#import "IPCController.h"
 
 #import <Growl/Growl.h>
 
 @class TorrentTableView;
+@class StatusBarView;
+@class FilterButton;
+
+typedef enum
+{
+    ADD_MANUAL,
+    ADD_AUTO,
+    ADD_SHOW_OPTIONS,
+    ADD_URL,
+    ADD_CREATED
+} addType;
 
 @interface Controller : NSObject <GrowlApplicationBridgeDelegate>
 {
-    tr_handle                       * fLib;
+    tr_session                       * fLib;
     
     NSMutableArray                  * fTorrents, * fDisplayedTorrents;
     
     PrefsController                 * fPrefsController;
     InfoWindowController            * fInfoController;
     MessageWindowController         * fMessageController;
-    IPCController                   * fIPCController;
     
     NSUserDefaults                  * fDefaults;
     
     IBOutlet NSWindow               * fWindow;
     DragOverlayWindow               * fOverlayWindow;
-    IBOutlet NSScrollView           * fScrollView;
     IBOutlet TorrentTableView       * fTableView;
+
+    io_connect_t                    fRootPort;
+    NSTimer                         * fTimer;
     
     IBOutlet NSMenuItem             * fOpenIgnoreDownloadFolder;
-    
-    IBOutlet StatusBarView          * fBottomTigerBar;
-    IBOutlet NSBox                  * fBottomTigerLine;
     IBOutlet NSButton               * fActionButton, * fSpeedLimitButton;
-    NSTimer                         * fSpeedLimitTimer;
     IBOutlet NSTextField            * fTotalTorrentsField;
     
     IBOutlet StatusBarView          * fStatusBar;
     IBOutlet NSButton               * fStatusButton;
-    IBOutlet MenuLabel              * fStatusTigerField;
-    IBOutlet NSImageView            * fStatusTigerImageView;
     IBOutlet NSTextField            * fTotalDLField, * fTotalULField;
+    IBOutlet NSImageView            * fTotalDLImageView;
     
     IBOutlet StatusBarView          * fFilterBar;
     IBOutlet FilterButton           * fNoFilterButton, * fActiveFilterButton, * fDownloadFilterButton,
@@ -82,6 +86,7 @@
     IBOutlet NSMenuItem             * fUploadLimitItem, * fUploadNoLimitItem,
                                     * fDownloadLimitItem, * fDownloadNoLimitItem;
     
+    IBOutlet NSMenu                 * fRatioStopMenu;
     IBOutlet NSMenuItem             * fCheckRatioItem, * fNoCheckRatioItem;
     
     IBOutlet NSMenu                 * fGroupsSetMenu, * fGroupsSetContextMenu, * fGroupFilterMenu;
@@ -89,12 +94,10 @@
     
     IBOutlet NSWindow               * fURLSheetWindow;
     IBOutlet NSTextField            * fURLSheetTextField;
-
-    io_connect_t                    fRootPort;
-    NSTimer                         * fTimer;
+    IBOutlet NSButton               * fURLSheetOpenButton;
     
-    IBOutlet SUUpdater              * fUpdater;
     BOOL                            fUpdateInProgress;
+    BOOL                            fPauseOnLaunch;
     
     Badger                          * fBadger;
     IBOutlet NSMenu                 * fDockMenu;
@@ -103,20 +106,17 @@
     NSTimer                         * fAutoImportTimer;
     
     NSMutableDictionary             * fPendingTorrentDownloads;
-    NSMutableArray                  * fTempTorrentFiles;
-
-    BOOL                            fRemoteQuit;
+    
+    BOOL                            fSoundPlaying;
 }
 
-- (void) openFiles:             (NSArray *) filenames;
-- (void) openFiles:             (NSArray *) filenames forcePath: (NSString *) path ignoreDownloadFolder: (BOOL) ignore
-                                            deleteTorrentFile: (torrentFileState) deleteTorrent;
+- (void) openFiles:             (NSArray *) filenames addType: (addType) type forcePath: (NSString *) path;
+- (void) askOpenConfirmed:      (AddWindowController *) addController add: (BOOL) add;
 - (void) openCreatedFile:       (NSNotification *) notification;
 - (void) openFilesWithDict:     (NSDictionary *) dictionary;
-- (void) openFilesAsk:          (NSMutableArray *) files deleteTorrentFile: (torrentFileState) deleteTorrent;
-- (void) openFilesAskWithDict:  (NSDictionary *) dictionary;
 - (void) openShowSheet:         (id) sender;
 
+- (void) invalidOpenAlert: (NSString *) filename;
 - (void) duplicateOpenAlert: (NSString *) name;
 
 - (void) openURL:               (NSURL *) torrentURL;
@@ -124,7 +124,7 @@
 - (void) openURLCancelEndSheet: (id) sender;
 - (void) openURLShowSheet:      (id) sender;
 
-- (void) quitSheetDidEnd: (NSWindow *) sheet returnCode: (int) returnCode contextInfo: (void *) contextInfo;
+- (void) quitSheetDidEnd: (NSWindow *) sheet returnCode: (NSInteger) returnCode contextInfo: (void *) contextInfo;
 
 - (void) createFile: (id) sender;
 
@@ -140,19 +140,16 @@
 - (void) stopAllTorrents:           (id) sender;
 - (void) stopTorrents:              (NSArray *) torrents;
 
-- (void) removeTorrents: (NSArray *) torrents
-        deleteData: (BOOL) deleteData deleteTorrent: (BOOL) deleteData;
-- (void) removeSheetDidEnd: (NSWindow *) sheet returnCode: (int) returnCode
+- (void) removeTorrents: (NSArray *) torrents deleteData: (BOOL) deleteData;
+- (void) removeSheetDidEnd: (NSWindow *) sheet returnCode: (NSInteger) returnCode
                         contextInfo: (NSDictionary *) dict;
-- (void) confirmRemoveTorrents: (NSArray *) torrents
-        deleteData: (BOOL) deleteData deleteTorrent: (BOOL) deleteTorrent;
+- (void) confirmRemoveTorrents: (NSArray *) torrents deleteData: (BOOL) deleteData;
 - (void) removeNoDelete:                (id) sender;
 - (void) removeDeleteData:              (id) sender;
-- (void) removeDeleteTorrent:           (id) sender;
-- (void) removeDeleteDataAndTorrent:    (id) sender;
 
-- (void) moveDataFiles: (id) sender;
-- (void) moveDataFileChoiceClosed: (NSOpenPanel *) panel returnCode: (int) code contextInfo: (NSArray *) torrents;
+- (void) moveDataFilesSelected: (id) sender;
+- (void) moveDataFiles: (NSArray *) torrents;
+- (void) moveDataFileChoiceClosed: (NSOpenPanel *) panel returnCode: (NSInteger) code contextInfo: (NSArray *) torrents;
 
 - (void) copyTorrentFiles: (id) sender;
 - (void) copyTorrentFileForTorrents: (NSMutableArray *) torrents;
@@ -161,13 +158,15 @@
 
 - (void) announceSelectedTorrents: (id) sender;
 
-- (void) resetCacheForSelectedTorrents: (id) sender;
+- (void) verifySelectedTorrents: (id) sender;
+- (void) verifyTorrents: (NSArray *) torrents;
 
 - (void) showPreferenceWindow: (id) sender;
 
 - (void) showAboutWindow: (id) sender;
 
 - (void) showInfo: (id) sender;
+- (void) resetInfo;
 - (void) setInfoTab: (id) sender;
 
 - (void) showMessageWindow: (id) sender;
@@ -175,36 +174,42 @@
 
 - (void) updateUI;
 
+- (void) resizeStatusButton;
+- (void) setBottomCountText: (BOOL) filtering;
+
+- (void) updateSpeedFieldsToolTips;
+
 - (void) updateTorrentsInQueue;
-- (int) numToStartFromQueue: (BOOL) downloadQueue;
+- (NSInteger) numToStartFromQueue: (BOOL) downloadQueue;
 
 - (void) torrentFinishedDownloading: (NSNotification *) notification;
 - (void) torrentRestartedDownloading: (NSNotification *) notification;
+- (void) torrentStoppedForRatio: (NSNotification *) notification;
 
 - (void) updateTorrentHistory;
 
+- (void) applyFilter: (id) sender;
+
 - (void) sortTorrents;
 - (void) sortTorrentsIgnoreSelected;
 - (void) setSort: (id) sender;
 - (void) setSortByGroup: (id) sender;
 - (void) setSortReverse: (id) sender;
 
-- (void) applyFilter: (id) sender;
 - (void) setFilter: (id) sender;
 - (void) setFilterSearchType: (id) sender;
 - (void) switchFilter: (id) sender;
 
 - (void) setStatusLabel: (id) sender;
 
-- (void) showGroups: (id) sender;
 - (void) setGroup: (id) sender; //used by delegate-generated menu items
 - (void) setGroupFilter: (id) sender;
 - (void) updateGroupsFilterButton;
 - (void) updateGroupsFilters: (NSNotification *) notification;
 
 - (void) toggleSpeedLimit: (id) sender;
-- (void) autoSpeedLimitChange: (NSNotification *) notification;
-- (void) autoSpeedLimit;
+- (void) speedLimitChanged: (id) sender;
+- (void) altSpeedToggledCallbackIsLimited: (NSDictionary *) dict;
 
 - (void) setLimitGlobalEnabled: (id) sender;
 - (void) setQuickLimitGlobal: (id) sender;
@@ -212,25 +217,25 @@
 - (void) setRatioGlobalEnabled: (id) sender;
 - (void) setQuickRatioGlobal: (id) sender;
 
-- (void) torrentStoppedForRatio: (NSNotification *) notification;
-
 - (void) changeAutoImport;
 - (void) checkAutoImportDirectory;
 
 - (void) beginCreateFile: (NSNotification *) notification;
 
-- (void) sleepCallBack: (natural_t) messageType argument: (void *) messageArgument;
+- (void) sleepCallback: (natural_t) messageType argument: (void *) messageArgument;
 
 - (void) torrentTableViewSelectionDidChange: (NSNotification *) notification;
 
 - (void) toggleSmallView: (id) sender;
 - (void) togglePiecesBar: (id) sender;
 - (void) toggleAvailabilityBar: (id) sender;
+- (void) toggleStatusString: (id) sender;
 
 - (void) toggleStatusBar: (id) sender;
 - (void) showStatusBar: (BOOL) show animate: (BOOL) animate;
 - (void) toggleFilterBar: (id) sender;
 - (void) showFilterBar: (BOOL) show animate: (BOOL) animate;
+- (void) focusFilterField;
 
 - (void) allToolbarClicked: (id) sender;
 - (void) selectedToolbarClicked: (id) sender;
@@ -238,12 +243,25 @@
 - (void) setWindowSizeToFit;
 - (NSRect) sizedWindowFrame;
 
+- (void) updateForExpandCollape;
+
 - (void) showMainWindow: (id) sender;
 
+- (NSArray *) quickLookURLs;
+- (BOOL) canQuickLook;
+- (BOOL) canQuickLookTorrent: (Torrent *) torrent;
+- (NSRect) quickLookFrameWithURL: (NSURL*) url;
+- (void) toggleQuickLook: (id) sender;
+
 - (void) linkHomepage: (id) sender;
 - (void) linkForums: (id) sender;
+- (void) linkTrac: (id) sender;
 - (void) linkDonate: (id) sender;
 
-- (void) prepareForUpdate:  (NSNotification *) notification;
+- (void) rpcCallback: (tr_rpc_callback_type) type forTorrentStruct: (struct tr_torrent *) torrentStruct;
+- (void) rpcAddTorrentStruct: (NSValue *) torrentStructPtr;
+- (void) rpcRemoveTorrent: (Torrent *) torrent;
+- (void) rpcStartedStoppedTorrent: (Torrent *) torrent;
+- (void) rpcChangedTorrent: (Torrent *) torrent;
 
 @end
