@@ -1,7 +1,7 @@
 /******************************************************************************
- * $Id: CreatorWindowController.m 7780 2009-01-23 02:39:42Z livings124 $
+ * $Id: CreatorWindowController.m 9103 2009-09-12 01:01:02Z livings124 $
  *
- * Copyright (c) 2007-2008 Transmission authors and contributors
+ * Copyright (c) 2007-2009 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -23,7 +23,6 @@
  *****************************************************************************/
 
 #import "CreatorWindowController.h"
-#import "NSApplicationAdditions.h"
 #import "NSStringAdditions.h"
 #import "utils.h" //tr_httpIsValidURL
 
@@ -69,7 +68,7 @@
         fStarted = NO;
         
         fPath = [path retain];
-        fInfo = tr_metaInfoBuilderCreate(handle, [fPath UTF8String]);
+        fInfo = tr_metaInfoBuilderCreate([fPath UTF8String]);
         
         if (fInfo->fileCount == 0)
         {
@@ -184,13 +183,6 @@
     
     fOpenTorrent = [fDefaults boolForKey: @"CreatorOpen"];
     [self updateEnableOpenCheckForTrackers];
-    
-    if (![NSApp isOnLeopardOrBetter])
-    {
-        [fTrackerAddRemoveControl sizeToFit];
-        [fTrackerAddRemoveControl setLabel: @"+" forSegment: TRACKER_ADD_TAG];
-        [fTrackerAddRemoveControl setLabel: @"-" forSegment: TRACKER_REMOVE_TAG];
-    }
 }
 
 - (void) dealloc
@@ -221,7 +213,7 @@
     [panel setMessage: NSLocalizedString(@"Select the name and location for the torrent file.",
                                         "Create torrent -> location sheet -> message")]; 
     
-    [panel setRequiredFileType: @"torrent"];
+    [panel setAllowedFileTypes: [NSArray arrayWithObjects: @"org.bittorrent.torrent", @"torrent", nil]];
     [panel setCanSelectHiddenExtension: YES];
     
     [panel beginSheetForDirectory: [fLocation stringByDeletingLastPathComponent] file: [fLocation lastPathComponent]
@@ -231,6 +223,10 @@
 
 - (void) create: (id) sender
 {
+    //make sure the trackers are no longer being verified
+    if ([fTrackerTable editedRow] != -1)
+        [[self window] endEditingFor: fTrackerTable];
+    
     if ([fTrackers count] == 0 && [fDefaults boolForKey: @"WarningCreatorBlankAddress"])
     {
         NSAlert * alert = [[NSAlert alloc] init];
@@ -240,11 +236,7 @@
             " that will add the address for you.", "Create torrent -> blank address -> message")];
         [alert addButtonWithTitle: NSLocalizedString(@"Create", "Create torrent -> blank address -> button")];
         [alert addButtonWithTitle: NSLocalizedString(@"Cancel", "Create torrent -> blank address -> button")];
-        
-        if ([NSApp isOnLeopardOrBetter])
-            [alert setShowsSuppressionButton: YES];
-        else
-            [alert addButtonWithTitle: NSLocalizedString(@"Don't Alert Again", "Create torrent -> blank address -> button")];
+        [alert setShowsSuppressionButton: YES];
 
         [alert beginSheetModalForWindow: [self window] modalDelegate: self
             didEndSelector: @selector(createBlankAddressAlertDidEnd:returnCode:contextInfo:) contextInfo: nil];
@@ -299,8 +291,8 @@
         [fTrackers addObject: @""];
         [fTrackerTable reloadData];
         
-        NSInteger row = [fTrackers count] - 1;
-        [fTrackerTable selectRow: row byExtendingSelection: NO];
+        const NSInteger row = [fTrackers count] - 1;
+        [fTrackerTable selectRowIndexes: [NSIndexSet indexSetWithIndex: row] byExtendingSelection: NO];
         [fTrackerTable editColumn: 0 row: row withEvent: nil select: YES];
     }
 }
@@ -377,7 +369,7 @@
 
 - (void) createBlankAddressAlertDidEnd: (NSAlert *) alert returnCode: (NSInteger) returnCode contextInfo: (void *) contextInfo
 {
-    if (([NSApp isOnLeopardOrBetter] ? [[alert suppressionButton] state] == NSOnState : returnCode == NSAlertThirdButtonReturn))
+    if ([[alert suppressionButton] state] == NSOnState)
         [[NSUserDefaults standardUserDefaults] setBool: NO forKey: @"WarningCreatorBlankAddress"];
     
     [alert release];
@@ -473,7 +465,7 @@
                         NSLocalizedString(@"An unknown error has occurred.", "Create torrent -> failed -> warning"), fInfo->result]];
                 
                 [alert beginSheetModalForWindow: [self window] modalDelegate: self
-                        didEndSelector: @selector(failureSheetClosed:returnCode:contextInfo:) contextInfo: nil];
+                    didEndSelector: @selector(failureSheetClosed:returnCode:contextInfo:) contextInfo: nil];
         }
     }
     else
@@ -487,6 +479,7 @@
             [fProgressView setHidden: YES];
             
             NSWindow * window = [self window];
+            [window setFrameAutosaveName: @""];
             
             NSRect windowRect = [window frame];
             CGFloat difference = [fProgressView frame].size.height - [[window contentView] frame].size.height;
