@@ -1,7 +1,7 @@
 /******************************************************************************
- * $Id: PrefsController.h 7666 2009-01-11 18:04:45Z livings124 $
+ * $Id: PrefsController.h 8461 2009-05-21 04:35:40Z livings124 $
  *
- * Copyright (c) 2005-2008 Transmission authors and contributors
+ * Copyright (c) 2005-2009 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -32,7 +32,7 @@
     NSUserDefaults * fDefaults;
     BOOL fHasLoaded;
     
-    IBOutlet NSView * fGeneralView, * fTransfersView, * fBandwidthView, * fPeersView, * fNetworkView, * fRemoteView;
+    IBOutlet NSView * fGeneralView, * fTransfersView, * fBandwidthView, * fPeersView, * fNetworkView, * fRemoteView, * fGroupsView;
     
     NSString * fInitialString;
     
@@ -41,6 +41,7 @@
 
     IBOutlet NSTextField * fUploadField, * fDownloadField,
                         * fSpeedLimitUploadField, * fSpeedLimitDownloadField;
+    IBOutlet NSPopUpButton * fAutoSpeedDayTypePopUp;
     
     IBOutlet NSTextField * fPeersGlobalField, * fPeersTorrentField, * fBlocklistMessageField, * fBlocklistDateField;
     IBOutlet NSButton * fBlocklistEnableCheck;
@@ -60,12 +61,17 @@
     IBOutlet NSTableView * fRPCWhitelistTable;
     NSMutableArray * fRPCWhitelistArray;
     IBOutlet NSSegmentedControl * fRPCAddRemoveControl;
+    NSString * fRPCPassword;
 }
 
 + (void) setHandle: (tr_session *) handle;
 + (tr_session *) handle;
 
+- (void) setAutoUpdateToBeta: (id) sender;
+
 - (void) setPort: (id) sender;
+- (void) randomPort: (id) sender;
+- (void) setRandomPortOnStart: (id) sender;
 - (void) setNat: (id) sender;
 - (void) updatePortStatus;
 - (void) portCheckerDidFinishProbing: (PortChecker *) portChecker;
@@ -77,6 +83,7 @@
 - (void) setPeersTorrent: (id) sender;
 
 - (void) setPEX: (id) sender;
+- (void) setDHT: (id) sender;
 
 - (void) setEncryptionMode: (id) sender;
 
@@ -103,12 +110,17 @@
 - (void) setRatioStop: (id) sender;
 
 - (void) applySpeedSettings: (id) sender;
+- (void) applyAltSpeedSettings;
 
 - (void) updateLimitFields;
 - (void) setGlobalLimit: (id) sender;
 
 - (void) setSpeedLimit: (id) sender;
 - (void) setAutoSpeedLimit: (id) sender;
+- (void) setAutoSpeedLimitTime: (id) sender;
+- (void) setAutoSpeedLimitDay: (id) sender;
++ (NSInteger) dateToTimeSum: (NSDate *) date;
++ (NSDate *) timeSumToDate: (NSInteger) sum;
 
 - (void) setAutoImport: (id) sender;
 - (void) importFolderSheetShow: (id) sender;
@@ -133,6 +145,7 @@
 - (void) updateRPCPassword;
 - (void) setRPCPort: (id) sender;
 - (void) setRPCUseWhitelist: (id) sender;
+- (void) setRPCWebUIDiscovery: (id) sender;
 - (void) updateRPCWhitelist;
 - (void) addRemoveRPCIP: (id) sender;
 
