@@ -1,7 +1,7 @@
 /******************************************************************************
- * $Id: TorrentCell.m 6252 2008-06-25 05:01:04Z livings124 $
+ * $Id: TorrentCell.m 8870 2009-08-05 01:55:37Z livings124 $
  *
- * Copyright (c) 2006-2008 Transmission authors and contributors
+ * Copyright (c) 2006-2009 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -25,35 +25,37 @@
 #import "TorrentCell.h"
 #import "TorrentTableView.h"
 #import "GroupsController.h"
-#import "NSApplicationAdditions.h"
 #import "NSStringAdditions.h"
-#import "NSBezierPathAdditions.h"
-#import "CTGradientAdditions.h"
+#import "ProgressGradients.h"
 
-#define BAR_HEIGHT 12.0
+#define BAR_HEIGHT 12.0f
 
-#define IMAGE_SIZE_REG 32.0
-#define IMAGE_SIZE_MIN 16.0
+#define IMAGE_SIZE_REG 32.0f
+#define IMAGE_SIZE_MIN 16.0f
 
-#define NORMAL_BUTTON_WIDTH 14.0
-#define ACTION_BUTTON_WIDTH 16.0
+#define NORMAL_BUTTON_WIDTH 14.0f
+#define ACTION_BUTTON_WIDTH 16.0f
+
+#define PRIORITY_ICON_WIDTH 14.0f
+#define PRIORITY_ICON_HEIGHT 14.0f
 
 //ends up being larger than font height
-#define HEIGHT_TITLE 16.0
-#define HEIGHT_STATUS 12.0
+#define HEIGHT_TITLE 16.0f
+#define HEIGHT_STATUS 12.0f
 
-#define PADDING_HORIZONTAL 3.0
-#define PADDING_BETWEEN_IMAGE_AND_TITLE 5.0
-#define PADDING_BETWEEN_IMAGE_AND_BAR 7.0
-#define PADDING_ABOVE_TITLE 4.0
-#define PADDING_ABOVE_MIN_STATUS 4.0
-#define PADDING_BETWEEN_TITLE_AND_MIN_STATUS 2.0
-#define PADDING_BETWEEN_TITLE_AND_PROGRESS 1.0
-#define PADDING_BETWEEN_PROGRESS_AND_BAR 2.0
-#define PADDING_BETWEEN_TITLE_AND_BAR_MIN 3.0
-#define PADDING_BETWEEN_BAR_AND_STATUS 2.0
+#define PADDING_HORIZONTAL 3.0f
+#define PADDING_BETWEEN_IMAGE_AND_TITLE 5.0f
+#define PADDING_BETWEEN_IMAGE_AND_BAR 7.0f
+#define PADDING_BETWEEN_TITLE_AND_PRIORITY 4.0f
+#define PADDING_ABOVE_TITLE 4.0f
+#define PADDING_ABOVE_MIN_STATUS 4.0f
+#define PADDING_BETWEEN_TITLE_AND_MIN_STATUS 2.0f
+#define PADDING_BETWEEN_TITLE_AND_PROGRESS 1.0f
+#define PADDING_BETWEEN_PROGRESS_AND_BAR 2.0f
+#define PADDING_BETWEEN_TITLE_AND_BAR_MIN 3.0f
+#define PADDING_BETWEEN_BAR_AND_STATUS 2.0f
 
-#define PIECES_TOTAL_PERCENT 0.6
+#define PIECES_TOTAL_PERCENT 0.6f
 
 #define MAX_PIECES (18*18)
 
@@ -91,26 +93,32 @@
         [paragraphStyle setLineBreakMode: NSLineBreakByTruncatingTail];
     
         fTitleAttributes = [[NSMutableDictionary alloc] initWithObjectsAndKeys:
-                                [NSFont messageFontOfSize: 12.0], NSFontAttributeName,
+                                [NSFont messageFontOfSize: 12.0f], NSFontAttributeName,
                                 paragraphStyle, NSParagraphStyleAttributeName, nil];
         fStatusAttributes = [[NSMutableDictionary alloc] initWithObjectsAndKeys:
-                                [NSFont messageFontOfSize: 9.0], NSFontAttributeName,
+                                [NSFont messageFontOfSize: 9.0f], NSFontAttributeName,
                                 paragraphStyle, NSParagraphStyleAttributeName, nil];
         [paragraphStyle release];
         
-        fBluePieceColor = [[NSColor colorWithCalibratedRed: 0.0 green: 0.4 blue: 0.8 alpha: 1.0] retain];
-        fBarBorderColor = [[NSColor colorWithDeviceWhite: 0.0 alpha: 0.2] retain];
+        fBluePieceColor = [[NSColor colorWithCalibratedRed: 0.0f green: 0.4f blue: 0.8f alpha: 1.0f] retain];
+        fBarBorderColor = [[NSColor colorWithCalibratedWhite: 0.0f alpha: 0.2f] retain];
+        
+        fHighPriorityImage = [[NSImage imageNamed: @"PriorityHigh.png"] copy];
+        [fHighPriorityImage setFlipped: YES];
+        
+        fLowPriorityImage = [[NSImage imageNamed: @"PriorityLow.png"] copy];
+        [fLowPriorityImage setFlipped: YES];
     }
 	return self;
 }
 
 - (NSRect) iconRectForBounds: (NSRect) bounds
 {
-    float imageSize = [fDefaults boolForKey: @"SmallView"] ? IMAGE_SIZE_MIN : IMAGE_SIZE_REG;
+    CGFloat imageSize = [fDefaults boolForKey: @"SmallView"] ? IMAGE_SIZE_MIN : IMAGE_SIZE_REG;
     
     NSRect result = bounds;
     result.origin.x += PADDING_HORIZONTAL;
-    result.origin.y += floorf((result.size.height - imageSize) * 0.5);
+    result.origin.y += floorf((result.size.height - imageSize) * 0.5f);
     result.size = NSMakeSize(imageSize, imageSize);
     
     return result;
@@ -154,7 +162,7 @@
     else
         result.origin.y += PADDING_BETWEEN_TITLE_AND_PROGRESS + HEIGHT_STATUS + PADDING_BETWEEN_PROGRESS_AND_BAR;
     
-    result.size.width = round(NSMaxX(bounds) - result.origin.x - PADDING_HORIZONTAL - 2.0 * (PADDING_HORIZONTAL + NORMAL_BUTTON_WIDTH));
+    result.size.width = round(NSMaxX(bounds) - result.origin.x - PADDING_HORIZONTAL - 2.0f * (PADDING_HORIZONTAL + NORMAL_BUTTON_WIDTH));
     
     return result;
 }
@@ -172,9 +180,9 @@
     NSRect result = bounds;
     result.size.height = NORMAL_BUTTON_WIDTH;
     result.size.width = NORMAL_BUTTON_WIDTH;
-    result.origin.x = NSMaxX(bounds) - 2.0 * (PADDING_HORIZONTAL + NORMAL_BUTTON_WIDTH);
+    result.origin.x = NSMaxX(bounds) - 2.0f * (PADDING_HORIZONTAL + NORMAL_BUTTON_WIDTH);
     
-    result.origin.y += PADDING_ABOVE_TITLE + HEIGHT_TITLE - (NORMAL_BUTTON_WIDTH - BAR_HEIGHT) * 0.5;
+    result.origin.y += PADDING_ABOVE_TITLE + HEIGHT_TITLE - (NORMAL_BUTTON_WIDTH - BAR_HEIGHT) * 0.5f;
     if ([fDefaults boolForKey: @"SmallView"])
         result.origin.y += PADDING_BETWEEN_TITLE_AND_BAR_MIN;
     else
@@ -190,7 +198,7 @@
     result.size.width = NORMAL_BUTTON_WIDTH;
     result.origin.x = NSMaxX(bounds) - (PADDING_HORIZONTAL + NORMAL_BUTTON_WIDTH);
     
-    result.origin.y += PADDING_ABOVE_TITLE + HEIGHT_TITLE - (NORMAL_BUTTON_WIDTH - BAR_HEIGHT) * 0.5;
+    result.origin.y += PADDING_ABOVE_TITLE + HEIGHT_TITLE - (NORMAL_BUTTON_WIDTH - BAR_HEIGHT) * 0.5f;
     if ([fDefaults boolForKey: @"SmallView"])
         result.origin.y += PADDING_BETWEEN_TITLE_AND_BAR_MIN;
     else
@@ -204,8 +212,8 @@
     NSRect result = [self iconRectForBounds: bounds];
     if (![fDefaults boolForKey: @"SmallView"])
     {
-        result.origin.x += (result.size.width - ACTION_BUTTON_WIDTH) * 0.5;
-        result.origin.y += (result.size.height - ACTION_BUTTON_WIDTH) * 0.5;
+        result.origin.x += (result.size.width - ACTION_BUTTON_WIDTH) * 0.5f;
+        result.origin.y += (result.size.height - ACTION_BUTTON_WIDTH) * 0.5f;
         result.size.width = ACTION_BUTTON_WIDTH;
         result.size.height = ACTION_BUTTON_WIDTH;
     }
@@ -293,8 +301,7 @@
     }
     else;
     
-    if ([NSApp isOnLeopardOrBetter])
-        [controlView updateTrackingAreas];
+    [controlView updateTrackingAreas];
     
     return YES;
 }
@@ -378,40 +385,41 @@
 {
     Torrent * torrent = [self representedObject];
     
-    BOOL minimal = [fDefaults boolForKey: @"SmallView"];
+    const BOOL minimal = [fDefaults boolForKey: @"SmallView"];
     
     //group coloring
     NSRect iconRect = [self iconRectForBounds: cellFrame];
     
-    int groupValue = [torrent groupValue];
+    NSInteger groupValue = [torrent groupValue];
     if (groupValue != -1)
     {
-        NSRect groupRect = NSInsetRect(iconRect, -1.0, -2.0);
+        NSRect groupRect = NSInsetRect(iconRect, -1.0f, -2.0f);
         if (!minimal)
         {
             groupRect.size.height--;
             groupRect.origin.y--;
         }
-        float radius = minimal ? 3.0 : 6.0;
+        const CGFloat radius = minimal ? 3.0f : 6.0f;
         
         NSColor * groupColor = [[GroupsController groups] colorForIndex: groupValue],
-                * darkGroupColor = [groupColor blendedColorWithFraction: 0.2 ofColor: [NSColor whiteColor]];
+                * darkGroupColor = [groupColor blendedColorWithFraction: 0.2f ofColor: [NSColor whiteColor]];
         
         //border
-        NSBezierPath * bp = [NSBezierPath bezierPathWithRoundedRect: groupRect radius: radius];
+        NSBezierPath * bp = [NSBezierPath bezierPathWithRoundedRect: groupRect xRadius: radius yRadius: radius];
         [darkGroupColor set];
-        [bp setLineWidth: 2.0];
+        [bp setLineWidth: 2.0f];
         [bp stroke];
         
         //inside
-        bp = [NSBezierPath bezierPathWithRoundedRect: groupRect radius: radius];
-        CTGradient * gradient = [CTGradient gradientWithBeginningColor: [groupColor blendedColorWithFraction: 0.7
+        bp = [NSBezierPath bezierPathWithRoundedRect: groupRect xRadius: radius yRadius: radius];
+        NSGradient * gradient = [[NSGradient alloc] initWithStartingColor: [groupColor blendedColorWithFraction: 0.7f
                                     ofColor: [NSColor whiteColor]] endingColor: darkGroupColor];
-        [gradient fillBezierPath: bp angle: 90.0];
+        [gradient drawInBezierPath: bp angle: 90.0f];
+        [gradient release];
     }
     
     //error image
-    BOOL error = [torrent isError];
+    const BOOL error = [torrent isErrorOrWarning];
     if (error && !fErrorImage)
     {
         fErrorImage = [NSImage imageNamed: @"Error.png"];
@@ -422,24 +430,20 @@
     if (!minimal || !(!fTracking && fHoverAction)) //don't show in minimal mode when hovered over
     {
         NSImage * icon = (minimal && error) ? fErrorImage : [torrent icon];
-        [icon drawInRect: iconRect fromRect: NSZeroRect operation: NSCompositeSourceOver fraction: 1.0];
+        [icon drawInRect: iconRect fromRect: NSZeroRect operation: NSCompositeSourceOver fraction: 1.0f];
     }
     
     if (error && !minimal)
     {
         NSRect errorRect = NSMakeRect(NSMaxX(iconRect) - IMAGE_SIZE_MIN, NSMaxY(iconRect) - IMAGE_SIZE_MIN,
                                         IMAGE_SIZE_MIN, IMAGE_SIZE_MIN);
-        [fErrorImage drawInRect: errorRect fromRect: NSZeroRect operation: NSCompositeSourceOver fraction: 1.0];
+        [fErrorImage drawInRect: errorRect fromRect: NSZeroRect operation: NSCompositeSourceOver fraction: 1.0f];
     }
     
     //text color
     NSColor * titleColor, * statusColor;
-    if ([self isHighlighted]
-        && [[self highlightColorWithFrame: cellFrame inView: controlView] isEqual: [NSColor alternateSelectedControlColor]])
-    {
-        titleColor = [NSColor whiteColor];
-        statusColor = [NSColor whiteColor];
-    }
+    if ([self backgroundStyle] == NSBackgroundStyleDark)
+        titleColor = statusColor = [NSColor whiteColor];
     else
     {
         titleColor = [NSColor controlTextColor];
@@ -461,6 +465,17 @@
     NSRect titleRect = [self rectForTitleWithString: titleString basedOnMinimalStatusRect: minimalStatusRect inBounds: cellFrame];
     [titleString drawInRect: titleRect];
     
+    //priority icon
+    if ([torrent priority] != TR_PRI_NORMAL)
+    {
+        NSImage * priorityImage = [torrent priority] == TR_PRI_HIGH ? fHighPriorityImage : fLowPriorityImage;
+        
+        NSRect priorityRect = NSMakeRect(NSMaxX(titleRect) + PADDING_BETWEEN_TITLE_AND_PRIORITY,
+                                titleRect.origin.y - (PRIORITY_ICON_HEIGHT - titleRect.size.height) / 2.0,
+                                PRIORITY_ICON_WIDTH, PRIORITY_ICON_HEIGHT);
+        [priorityImage drawInRect: priorityRect fromRect: NSZeroRect operation: NSCompositeSourceOver fraction: 1.0];
+    }
+    
     //progress
     if (!minimal)
     {
@@ -497,7 +512,7 @@
     
     [controlImage setFlipped: YES];
     [controlImage drawInRect: [self controlButtonRectForBounds: cellFrame] fromRect: NSZeroRect operation: NSCompositeSourceOver
-        fraction: 1.0];
+        fraction: 1.0f];
     
     //reveal button
     NSString * revealImageString;
@@ -511,7 +526,7 @@
     NSImage * revealImage = [NSImage imageNamed: revealImageString];
     [revealImage setFlipped: YES];
     [revealImage drawInRect: [self revealButtonRectForBounds: cellFrame] fromRect: NSZeroRect operation: NSCompositeSourceOver
-        fraction: 1.0];
+        fraction: 1.0f];
     
     //action button
     NSString * actionImageString;
@@ -527,7 +542,7 @@
         NSImage * actionImage = [NSImage imageNamed: actionImageString];
         [actionImage setFlipped: YES];
         [actionImage drawInRect: [self actionButtonRectForBounds: cellFrame] fromRect: NSZeroRect operation: NSCompositeSourceOver
-            fraction: 1.0];
+            fraction: 1.0f];
     }
     
     //status
@@ -544,8 +559,8 @@
 
 - (void) drawBar: (NSRect) barRect
 {
-    float piecesBarPercent = [(TorrentTableView *)[self controlView] piecesBarPercent];
-    if (piecesBarPercent > 0.0)
+    CGFloat piecesBarPercent = [(TorrentTableView *)[self controlView] piecesBarPercent];
+    if (piecesBarPercent > 0.0f)
     {
         NSRect regularBarRect = barRect, piecesBarRect = barRect;
         piecesBarRect.size.height *= PIECES_TOTAL_PERCENT * piecesBarPercent;
@@ -563,32 +578,32 @@
     }
     
     [fBarBorderColor set];
-    [NSBezierPath strokeRect: NSInsetRect(barRect, 0.5, 0.5)];
+    [NSBezierPath strokeRect: NSInsetRect(barRect, 0.5f, 0.5f)];
 }
 
 - (void) drawRegularBar: (NSRect) barRect
 {
     Torrent * torrent = [self representedObject];
     
-    int leftWidth = barRect.size.width;
-    float progress = [torrent progress];
+    NSInteger leftWidth = barRect.size.width;
+    CGFloat progress = [torrent progress];
     
-    if (progress < 1.0)
+    if (progress < 1.0f)
     {
-        float rightProgress = 1.0 - progress, progressLeft = [torrent progressLeft];
-        int rightWidth = leftWidth * rightProgress;
+        CGFloat rightProgress = 1.0f - progress, progressLeft = [torrent progressLeft];
+        NSInteger rightWidth = leftWidth * rightProgress;
         leftWidth -= rightWidth;
         
         if (progressLeft < rightProgress)
         {
-            int rightNoIncludeWidth = rightWidth * ((rightProgress - progressLeft) / rightProgress);
+            NSInteger rightNoIncludeWidth = rightWidth * ((rightProgress - progressLeft) / rightProgress);
             rightWidth -= rightNoIncludeWidth;
             
             NSRect noIncludeRect = barRect;
             noIncludeRect.origin.x += barRect.size.width - rightNoIncludeWidth;
             noIncludeRect.size.width = rightNoIncludeWidth;
             
-            [[CTGradient progressLightGrayGradient] fillRect: noIncludeRect angle: 90];
+            [[ProgressGradients progressLightGrayGradient] drawInRect: noIncludeRect angle: 90];
         }
         
         if (rightWidth > 0)
@@ -596,7 +611,7 @@
             if ([torrent isActive] && ![torrent allDownloaded] && ![torrent isChecking]
                 && [fDefaults boolForKey: @"DisplayProgressBarAvailable"])
             {
-                int notAvailableWidth = ceil(rightWidth * [torrent notAvailableDesired]);
+                NSInteger notAvailableWidth = ceil(rightWidth * [torrent notAvailableDesired]);
                 if (notAvailableWidth > 0)
                 {
                     rightWidth -= notAvailableWidth;
@@ -605,7 +620,7 @@
                     notAvailableRect.origin.x += leftWidth + rightWidth;
                     notAvailableRect.size.width = notAvailableWidth;
                     
-                    [[CTGradient progressRedGradient] fillRect: notAvailableRect angle: 90];
+                    [[ProgressGradients progressRedGradient] drawInRect: notAvailableRect angle: 90];
                 }
             }
             
@@ -615,7 +630,7 @@
                 includeRect.origin.x += leftWidth;
                 includeRect.size.width = rightWidth;
                 
-                [[CTGradient progressWhiteGradient] fillRect: includeRect angle: 90];
+                [[ProgressGradients progressWhiteGradient] drawInRect: includeRect angle: 90];
             }
         }
     }
@@ -628,10 +643,10 @@
         if ([torrent isActive])
         {
             if ([torrent isChecking])
-                [[CTGradient progressYellowGradient] fillRect: completeRect angle: 90];
+                [[ProgressGradients progressYellowGradient] drawInRect: completeRect angle: 90];
             else if ([torrent isSeeding])
             {
-                int ratioLeftWidth = leftWidth * (1.0 - [torrent progressStopRatio]);
+                NSInteger ratioLeftWidth = leftWidth * (1.0f - [torrent progressStopRatio]);
                 leftWidth -= ratioLeftWidth;
                 
                 if (ratioLeftWidth > 0)
@@ -640,30 +655,30 @@
                     ratioLeftRect.origin.x += leftWidth;
                     ratioLeftRect.size.width = ratioLeftWidth;
                     
-                    [[CTGradient progressLightGreenGradient] fillRect: ratioLeftRect angle: 90];
+                    [[ProgressGradients progressLightGreenGradient] drawInRect: ratioLeftRect angle: 90];
                 }
                 
                 if (leftWidth > 0)
                 {
                     completeRect.size.width = leftWidth;
                     
-                    [[CTGradient progressGreenGradient] fillRect: completeRect angle: 90];
+                    [[ProgressGradients progressGreenGradient] drawInRect: completeRect angle: 90];
                 }
             }
             else
-                [[CTGradient progressBlueGradient] fillRect: completeRect angle: 90];
+                [[ProgressGradients progressBlueGradient] drawInRect: completeRect angle: 90];
         }
         else
         {
             if ([torrent waitingToStart])
             {
-                if ([torrent progressLeft] <= 0.0)
-                    [[CTGradient progressDarkGreenGradient] fillRect: completeRect angle: 90];
+                if ([torrent progressLeft] <= 0.0f)
+                    [[ProgressGradients progressDarkGreenGradient] drawInRect: completeRect angle: 90];
                 else
-                    [[CTGradient progressDarkBlueGradient] fillRect: completeRect angle: 90];
+                    [[ProgressGradients progressDarkBlueGradient] drawInRect: completeRect angle: 90];
             }
             else
-                [[CTGradient progressGrayGradient] fillRect: completeRect angle: 90];
+                [[ProgressGradients progressGrayGradient] drawInRect: completeRect angle: 90];
         }
     }
 }
@@ -672,7 +687,7 @@
 {
     Torrent * torrent = [self representedObject];
     
-    int pieceCount = MIN([torrent pieceCount], MAX_PIECES);
+    NSInteger pieceCount = MIN([torrent pieceCount], MAX_PIECES);
     float * piecesPercent = malloc(pieceCount * sizeof(float));
     [torrent getAmountFinished: piecesPercent size: pieceCount];
     
@@ -683,11 +698,10 @@
     NSIndexSet * previousFinishedIndexes = [torrent previousFinishedPieces];
     NSMutableIndexSet * finishedIndexes = [NSMutableIndexSet indexSet];
     
-    int i;
-    for (i = 0; i < pieceCount; i++)
+    for (NSInteger i = 0; i < pieceCount; i++)
     {
         NSColor * pieceColor;
-        if (piecesPercent[i] == 1.0)
+        if (piecesPercent[i] == 1.0f)
         {
             if (previousFinishedIndexes && ![previousFinishedIndexes containsIndex: i])
                 pieceColor = [NSColor orangeColor];
@@ -725,7 +739,7 @@
 - (NSRect) rectForTitleWithString: (NSAttributedString *) string basedOnMinimalStatusRect: (NSRect) statusRect
             inBounds: (NSRect) bounds
 {
-    BOOL minimal = [fDefaults boolForKey: @"SmallView"];
+    const BOOL minimal = [fDefaults boolForKey: @"SmallView"];
     
     NSRect result = bounds;
     result.origin.y += PADDING_ABOVE_TITLE;
@@ -733,7 +747,8 @@
     
     result.size = [string size];
     result.size.width = MIN(result.size.width, NSMaxX(bounds) - result.origin.x - PADDING_HORIZONTAL
-                            - (minimal ? PADDING_BETWEEN_TITLE_AND_MIN_STATUS + statusRect.size.width : 0));
+                - (minimal ? PADDING_BETWEEN_TITLE_AND_MIN_STATUS + statusRect.size.width : 0.0)
+                - ([[self representedObject] priority] != TR_PRI_NORMAL ? PRIORITY_ICON_WIDTH + PADDING_BETWEEN_TITLE_AND_PRIORITY: 0.0));
     
     return result;
 }
@@ -791,7 +806,7 @@
             return NSLocalizedString(@"Pause the transfer", "Torrent Table -> tooltip");
         else
         {
-            if ([[NSApp currentEvent] modifierFlags] & NSAlternateKeyMask && [fDefaults boolForKey: @"Queue"])
+            if ([[NSApp currentEvent] modifierFlags] & NSAlternateKeyMask)
                 return NSLocalizedString(@"Resume the transfer right away", "Torrent cell -> button info");
             else if ([torrent waitingToStart])
                 return NSLocalizedString(@"Stop waiting to start", "Torrent cell -> button info");
